Logistic Transition Function for new variant prevalence.
delta.RdUsed in the COVID-19 Delta/Alpha variants example but can be used to model any generic new variant that becomes prevalent over the old one over time.
Arguments
- x
Numeric vector representing time.
- scale
Scaling factor controlling the rate of transition.
- start
The time point at which the new variant appears.
Value
A numeric vector representing the transition effect for new variant prevalence, ranging between 0 and 1.